from setuptools import setup, find_packages

setup(
    name="mrc_mnc",
    version="0.1",
    author="yingkehuang",
    author_email="ykhuang@ihep.ac.cn",
    description="A brief description of your package",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
